@@ -191,6 +191,16 @@ def test_simple_multiline_with_empty_cells_headerless():
     assert_equal(expected, result)
 
 
+def test_github():
+    "Output: github with headers"
+    expected = '\n'.join(['| strings   |   numbers |',
+                          '|-----------|-----------|',
+                          '| spam      |   41.9999 |',
+                          '| eggs      |  451      |',])
+    result = tabulate(_test_table, _test_table_headers, tablefmt="github")
+    assert_equal(expected, result)
+
+
 def test_grid():
     "Output: grid with headers"
     expected = '\n'.join(['+-----------+-----------+',
@@ -204,6 +214,26 @@ def test_grid():
     assert_equal(expected, result)
 
 
+def test_grid_wide_characters():
+    "Output: grid with wide characters in headers"
+    try:
+        import wcwidth
+    except ImportError:
+        print("test_grid_wide_characters is skipped")
+        raise SkipTest()   # this test is optional
+    headers = list(_test_table_headers)
+    headers[1] = '配列'
+    expected = '\n'.join(['+-----------+----------+',
+                          '| strings   |     配列 |',
+                          '+===========+==========+',
+                          '| spam      |  41.9999 |',
+                          '+-----------+----------+',
+                          '| eggs      | 451      |',
+                          '+-----------+----------+',])
+    result = tabulate(_test_table, headers, tablefmt="grid")
+    assert_equal(expected, result)
+
+
 def test_grid_headerless():
     "Output: grid without headers"
     expected = '\n'.join(['+------+----------+',
@@ -916,6 +946,12 @@ def test_floatfmt_multi():
     expected = '0.1  0.123  0.12345'
     assert_equal(expected, result)
 
+def test_colalign_multi():
+    "Output: string columns with custom colalign"
+    result = tabulate([["one", "two"], ["three", "four"]], colalign=("right",), tablefmt="plain")
+    expected = '  one  two\nthree  four'
+    assert_equal(expected, result)
+
 def test_float_conversions():
     "Output: float format parsed"
     test_headers = ["str", "bad_float", "just_float", 'with_inf', 'with_nan', 'neg_inf']
